@@ -8,15 +8,15 @@ def home(request):
 
 
 def secret_list(request):
-    return render(
-        request, "secret_list.html", {"secret_files": models.SecretFile.objects.all()}
-    )
+    return render(request, "secret_list.html", {"secret_files": models.SecretFile.objects.all()})
+
 
 def secret_list_some_desc(request):
     return render(
         request, "secret_list_some_desc.html", {"secret_files": models.SecretFile.objects.all()}
     )
 
+
 def secret_list_nulls_first(request):
     return render(
         request,
@@ -34,15 +34,15 @@ def secret_list_nulls_last(request):
 
 
 def jinja_secret_list(request):
-    return render(
-        request, "secret_list.jinja2", {"secret_files": models.SecretFile.objects.all()}
-    )
+    return render(request, "secret_list.jinja2", {"secret_files": models.SecretFile.objects.all()})
+
 
 def jinja_secret_list_some_desc(request):
     return render(
         request, "secret_list_some_desc.jinja2", {"secret_files": models.SecretFile.objects.all()}
     )
 
+
 def jinja_secret_list_nulls_first(request):
     return render(
         request,
@@ -57,3 +57,19 @@ def jinja_secret_list_nulls_last(request):
         "secret_list_nulls_last.jinja2",
         {"secret_files": models.SecretFile.objects.all()},
     )
+
+
+def secret_list_css_classes(request):
+    return render(
+        request,
+        "secret_list_css_classes.html",
+        {"secret_files": models.SecretFile.objects.all()},
+    )
+
+
+def jinja_secret_list_css_classes(request):
+    return render(
+        request,
+        "secret_list_css_classes.jinja2",
+        {"secret_files": models.SecretFile.objects.all()},
+    )
